@@ -1,11 +1,12 @@
 import asyncio
 import hashlib
 import json
+import logging
 import os
 import sys
 import uuid
 from asyncio import Lock
-from typing import Iterable
+from typing import Iterable, Optional
 
 import pathspec
 import tabulate
@@ -14,9 +15,17 @@ from chromadb.api.models.AsyncCollection import AsyncCollection
 from chromadb.api.types import IncludeEnum
 
 from vectorcode.chunking import Chunk, TreeSitterChunker
-from vectorcode.cli_utils import Config, expand_globs, expand_path
+from vectorcode.cli_utils import (
+    GLOBAL_EXCLUDE_SPEC,
+    GLOBAL_INCLUDE_SPEC,
+    Config,
+    expand_globs,
+    expand_path,
+)
 from vectorcode.common import get_client, get_collection, verify_ef
 
+logger = logging.getLogger(name=__name__)
+
 
 def hash_str(string: str) -> str:
     """Return the sha-256 hash of a string."""
@@ -49,9 +58,13 @@ async def chunked_add(
         )
 
     if num_existing_chunks:
+        logger.debug(
+            "Deleting %s existing chunks for the current file.", num_existing_chunks
+        )
         async with collection_lock:
             await collection.delete(where={"path": full_path_str})
 
+    logger.debug(f"Vectorising {file_path}")
     try:
         async with semaphore:
             chunks: list[Chunk | str] = list(
@@ -59,8 +72,10 @@ async def chunked_add(
             )
             if len(chunks) == 0 or (len(chunks) == 1 and chunks[0] == ""):
                 # empty file
+                logger.debug(f"Skipping {full_path_str} because it's empty.")
                 return
             chunks.append(str(os.path.relpath(full_path_str, configs.project_root)))
+            logger.debug(f"Chunked into {len(chunks)} pieces.")
             metas = []
             for chunk in chunks:
                 meta: dict[str, str | dict[str, int]] = {"path": full_path_str}
@@ -78,7 +93,7 @@ async def chunked_add(
                         metadatas=metas,
                     )
     except UnicodeDecodeError:  # pragma: nocover
-        # probably binary. skip it.
+        logger.warning(f"Failed to decode {full_path_str}.")
         return
 
     if num_existing_chunks:
@@ -120,12 +135,21 @@ def include_paths_by_spec(paths: Iterable[str], specs: pathspec.PathSpec) -> lis
 
 def load_files_from_include(project_root: str) -> list[str]:
     include_file_path = os.path.join(project_root, ".vectorcode", "vectorcode.include")
+    specs: Optional[pathspec.GitIgnoreSpec] = None
     if os.path.isfile(include_file_path):
+        logger.debug("Loading from local `vectorcode.include`.")
         with open(include_file_path) as fin:
-            specs = pathspec.PathSpec.from_lines(
-                pattern_factory="gitwildmatch",
+            specs = pathspec.GitIgnoreSpec.from_lines(
                 lines=(os.path.expanduser(i) for i in fin.readlines()),
             )
+    elif os.path.isfile(GLOBAL_INCLUDE_SPEC):
+        logger.debug("Loading from global `vectorcode.include`.")
+        with open(GLOBAL_INCLUDE_SPEC) as fin:
+            specs = pathspec.GitIgnoreSpec.from_lines(
+                lines=(os.path.expanduser(i) for i in fin.readlines()),
+            )
+    if specs is not None:
+        logger.info("Populating included files from loaded specs.")
         return [
             result.file
             for result in specs.check_tree_files(project_root)
@@ -144,12 +168,15 @@ async def vectorise(configs: Config) -> int:
         return 1
     if not verify_ef(collection, configs):
         return 1
-    gitignore_path = os.path.join(str(configs.project_root), ".gitignore")
+
     files = await expand_globs(
         configs.files or load_files_from_include(str(configs.project_root)),
         recursive=configs.recursive,
+        include_hidden=configs.include_hidden,
     )
+
     if not configs.force:
+        gitignore_path = os.path.join(str(configs.project_root), ".gitignore")
         specs = [
             gitignore_path,
         ]
@@ -158,11 +185,16 @@ async def vectorise(configs: Config) -> int:
         )
         if os.path.isfile(exclude_spec_path):
             specs.append(exclude_spec_path)
+        elif os.path.isfile(GLOBAL_EXCLUDE_SPEC):
+            specs.append(GLOBAL_EXCLUDE_SPEC)
         for spec_path in specs:
             if os.path.isfile(spec_path):
+                logger.info(f"Loading ignore specs from {spec_path}.")
                 with open(spec_path) as fin:
                     spec = pathspec.GitIgnoreSpec.from_lines(fin.readlines())
                 files = exclude_paths_by_spec((str(i) for i in files), spec)
+    else:  # pragma: nocover
+        logger.info("Ignoring exclude specs.")
 
     stats = {"add": 0, "update": 0, "removed": 0}
     collection_lock = Lock()
@@ -207,6 +239,7 @@ async def vectorise(configs: Config) -> int:
             async with stats_lock:
                 stats["removed"] = len(orphans)
             if len(orphans):
+                logger.info(f"Removing {len(orphans)} orphaned files from database.")
                 await collection.delete(where={"path": {"$in": list(orphans)}})
 
     show_stats(configs=configs, stats=stats)
