@@ -62,14 +62,16 @@ def mock_config():
 @pytest.mark.asyncio
 async def test_get_query_result_files(mock_collection, mock_config):
     # Mock the reranker
-    with patch("vectorcode.subcommands.query.reranker.NaiveReranker") as MockReranker:
+    with patch("vectorcode.subcommands.query.get_reranker") as mock_get_reranker:
         mock_reranker_instance = MagicMock()
-        mock_reranker_instance.rerank.return_value = [
-            "file1.py",
-            "file2.py",
-            "file3.py",
-        ]
-        MockReranker.return_value = mock_reranker_instance
+        mock_reranker_instance.rerank = AsyncMock(
+            return_value=[
+                "file1.py",
+                "file2.py",
+                "file3.py",
+            ]
+        )
+        mock_get_reranker.return_value = mock_reranker_instance
 
         # Call the function
         result = await get_query_result_files(mock_collection, mock_config)
@@ -87,7 +89,7 @@ async def test_get_query_result_files(mock_collection, mock_config):
         assert not kwargs["where"]  # Since query_exclude is empty
 
         # Check reranker was used correctly
-        MockReranker.assert_called_once_with(mock_config)
+        mock_get_reranker.assert_called_once_with(mock_config)
         mock_reranker_instance.rerank.assert_called_once_with(
             mock_collection.query.return_value
         )
@@ -103,7 +105,7 @@ async def test_get_query_result_files_include_chunk(mock_collection, mock_config
 
     with patch("vectorcode.subcommands.query.reranker.NaiveReranker") as MockReranker:
         mock_reranker_instance = MagicMock()
-        mock_reranker_instance.rerank.return_value = ["chunk1"]
+        mock_reranker_instance.rerank = AsyncMock(return_value=["chunk1"])
         MockReranker.return_value = mock_reranker_instance
 
         await get_query_result_files(mock_collection, mock_config)
@@ -188,7 +190,7 @@ async def test_get_query_result_files_with_query_exclude(mock_collection, mock_c
         mock_expand_path.return_value = "/excluded/path.py"
 
         mock_reranker_instance = MagicMock()
-        mock_reranker_instance.rerank.return_value = ["file1.py", "file2.py"]
+        mock_reranker_instance.rerank = AsyncMock(return_value=["file1.py", "file2.py"])
         MockReranker.return_value = mock_reranker_instance
 
         # Call the function
@@ -211,7 +213,7 @@ async def test_get_query_result_files_with_cross_encoder_reranker(
         "vectorcode.subcommands.query.reranker.CrossEncoderReranker"
     ) as MockCrossEncoder:
         mock_reranker_instance = MagicMock()
-        mock_reranker_instance.rerank.return_value = ["file1.py", "file2.py"]
+        mock_reranker_instance.rerank = AsyncMock(return_value=["file1.py", "file2.py"])
         MockCrossEncoder.return_value = mock_reranker_instance
 
         # Call the function
@@ -266,7 +268,7 @@ async def test_get_query_result_files_chunking(mock_collection, mock_config):
         MockChunker.return_value = mock_chunker_instance
 
         mock_reranker_instance = MagicMock()
-        mock_reranker_instance.rerank.return_value = ["file1.py", "file2.py"]
+        mock_reranker_instance.rerank = AsyncMock(return_value=["file1.py", "file2.py"])
         MockReranker.return_value = mock_reranker_instance
 
         # Call the function
@@ -300,7 +302,7 @@ async def test_get_query_result_files_multiple_queries(mock_collection, mock_con
         MockChunker.return_value = mock_chunker_instance
 
         mock_reranker_instance = MagicMock()
-        mock_reranker_instance.rerank.return_value = ["file1.py", "file2.py"]
+        mock_reranker_instance.rerank = AsyncMock(return_value=["file1.py", "file2.py"])
         MockReranker.return_value = mock_reranker_instance
 
         # Call the function
@@ -501,7 +503,6 @@ async def test_query_invalid_file(mock_config):
         patch("vectorcode.subcommands.query.verify_ef", return_value=True),
         patch("vectorcode.subcommands.query.get_query_result_files") as mock_get_files,
         patch("os.path.isfile", return_value=False),
-        patch("sys.stderr") as mock_stderr,
     ):
         # Set up the mock file paths
         mock_get_files.return_value = ["invalid_file.py"]
@@ -512,9 +513,6 @@ async def test_query_invalid_file(mock_config):
         # Verify the function completed successfully despite invalid file
         assert result == 0
 
-        # Check that a warning was printed to stderr
-        assert mock_stderr.write.called
-
 
 @pytest.mark.asyncio
 async def test_query_invalid_ef(mock_config):
@@ -560,7 +558,6 @@ async def test_query_chunk_mode_no_metadata_fallback(mock_config):
         ),
         patch("vectorcode.subcommands.query.verify_ef", return_value=True),
         patch("vectorcode.subcommands.query.build_query_results") as mock_build_results,
-        patch("sys.stderr") as mock_stderr,
     ):
         mock_build_results.return_value = []  # Return empty results for simplicity
 
@@ -571,11 +568,6 @@ async def test_query_chunk_mode_no_metadata_fallback(mock_config):
         # Verify the metadata check call
         mock_collection.get.assert_called_once_with(where={"start": {"$gte": 0}})
 
-        # Verify the warning was printed
-        assert mock_stderr.write.call_count > 0
-        call_args, _ = mock_stderr.write.call_args_list[0]
-        assert "Falling back to `--include path document`" in call_args[0]
-
         # Verify build_query_results was called with the *modified* config
         mock_build_results.assert_called_once()
         args, _ = mock_build_results.call_args
