@@ -41,6 +41,7 @@ async def test_config_import_from():
         }
         config = await Config.import_from(config_dict)
         assert config.db_path == db_path
+        assert config.db_log_path == os.path.expanduser("~/.local/share/vectorcode/")
         assert config.host == "test_host"
         assert config.port == 1234
         assert config.embedding_function == "TestEmbedding"
@@ -109,7 +110,7 @@ async def test_config_import_from_missing_keys():
     assert config.chunk_size == 2500
     assert config.overlap_ratio == 0.2
     assert config.query_multiplier == -1
-    assert config.reranker == "cross-encoder/ms-marco-MiniLM-L-6-v2"
+    assert config.reranker == "CrossEncoderReranker"
     assert config.reranker_params == {}
     assert config.db_settings is None
 
